DispatcherAPI
=============

.. currentmodule:: oda_api.api

.. autoclass:: DispatcherAPI
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DispatcherAPI.build_from_envs
      ~DispatcherAPI.dig_list
      ~DispatcherAPI.failure_report
      ~DispatcherAPI.generate_session_id
      ~DispatcherAPI.get_instrument_description
      ~DispatcherAPI.get_instruments_list
      ~DispatcherAPI.get_product
      ~DispatcherAPI.get_product_description
      ~DispatcherAPI.request
      ~DispatcherAPI.set_instr

   .. rubric:: Methods Documentation

   .. automethod:: build_from_envs
   .. automethod:: dig_list
   .. automethod:: failure_report
   .. automethod:: generate_session_id
   .. automethod:: get_instrument_description
   .. automethod:: get_instruments_list
   .. automethod:: get_product
   .. automethod:: get_product_description
   .. automethod:: request
   .. automethod:: set_instr
